@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -352,15 +352,12 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
-                always_use_jwt_access=(
-                    Transport == type(self).get_transport_class("grpc")
-                    or Transport == type(self).get_transport_class("grpc_asyncio")
-                ),
+                always_use_jwt_access=True,
             )
 
     def get_environment(
         self,
-        request: cloudshell.GetEnvironmentRequest = None,
+        request: Union[cloudshell.GetEnvironmentRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -371,7 +368,7 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
         not exist.
 
         Args:
-            request (google.cloud.shell_v1.types.GetEnvironmentRequest):
+            request (Union[google.cloud.shell_v1.types.GetEnvironmentRequest, dict]):
                 The request object. Request message for
                 [GetEnvironment][google.cloud.shell.v1.CloudShellService.GetEnvironment].
             name (str):
@@ -439,7 +436,7 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
 
     def start_environment(
         self,
-        request: cloudshell.StartEnvironmentRequest = None,
+        request: Union[cloudshell.StartEnvironmentRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -455,7 +452,7 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
         StartEnvironmentResponse in its response field.
 
         Args:
-            request (google.cloud.shell_v1.types.StartEnvironmentRequest):
+            request (Union[google.cloud.shell_v1.types.StartEnvironmentRequest, dict]):
                 The request object. Request message for
                 [StartEnvironment][google.cloud.shell.v1.CloudShellService.StartEnvironment].
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -507,7 +504,7 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
 
     def authorize_environment(
         self,
-        request: cloudshell.AuthorizeEnvironmentRequest = None,
+        request: Union[cloudshell.AuthorizeEnvironmentRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -520,7 +517,7 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
         authenticate.
 
         Args:
-            request (google.cloud.shell_v1.types.AuthorizeEnvironmentRequest):
+            request (Union[google.cloud.shell_v1.types.AuthorizeEnvironmentRequest, dict]):
                 The request object. Request message for
                 [AuthorizeEnvironment][google.cloud.shell.v1.CloudShellService.AuthorizeEnvironment].
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -571,7 +568,7 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
 
     def add_public_key(
         self,
-        request: cloudshell.AddPublicKeyRequest = None,
+        request: Union[cloudshell.AddPublicKeyRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -583,7 +580,7 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
         error with ALREADY_EXISTS.
 
         Args:
-            request (google.cloud.shell_v1.types.AddPublicKeyRequest):
+            request (Union[google.cloud.shell_v1.types.AddPublicKeyRequest, dict]):
                 The request object. Request message for
                 [AddPublicKey][google.cloud.shell.v1.CloudShellService.AddPublicKey].
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -636,7 +633,7 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
 
     def remove_public_key(
         self,
-        request: cloudshell.RemovePublicKeyRequest = None,
+        request: Union[cloudshell.RemovePublicKeyRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -648,7 +645,7 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
         present, this will error with NOT_FOUND.
 
         Args:
-            request (google.cloud.shell_v1.types.RemovePublicKeyRequest):
+            request (Union[google.cloud.shell_v1.types.RemovePublicKeyRequest, dict]):
                 The request object. Request message for
                 [RemovePublicKey][google.cloud.shell.v1.CloudShellService.RemovePublicKey].
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -699,6 +696,19 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
